-- COPIED FROM MHR: FRAME LIMITING FTW
local timestep = 1/60

function love.run()
  if love.math then
    love.math.setRandomSeed(os.time())
    for i = 1, 20 do
      love.math.random()
    end
  end
  if love.event then
    love.event.pump()
  end

  if love.load then love.load(arg) end
  if love.timer then love.timer.step() end

  local dt = 0
  local t = 0
  while true do
    -- Process events.
    if love.event then
      love.event.pump()
      for e,a,b,c,d in love.event.poll() do
        if e == "quit" then
          if not love.quit or not love.quit() then
            if love.audio then
              love.audio.stop()
            end
            return
          end
        end
        love.handlers[e](a,b,c,d)
      end
    end

    -- Update dt, as we'll be passing it to update
    if love.timer then
      love.timer.step()
      dt = love.timer.getDelta()
    end

    -- Call update and draw
    if love.update then
      t = math.min(1, t + dt)
      while t >= timestep do
        love.update(timestep)
        t = t - timestep
      end
    end

    if love.window and love.graphics and love.window.isCreated() then
      love.graphics.clear()
      love.graphics.origin()
      if love.draw then love.draw() end
      love.graphics.present()
    end

    if love.timer then love.timer.sleep(0.001) end

  end
end

------------------------------------------------------------------------------

function love.load()
  get_joystick()
  window_width = love.graphics.getWidth()
  window_height = love.graphics.getHeight()

  hamster = love.graphics.newImage("img/hamster.png")
  x = window_width / 2
  y = window_height / 2
  speed = 600
end

function love.update(dt)
  if love.keyboard.isDown("left") or joystick_01:isDown(12) then
    x = x - (speed * dt)
  end

  if love.keyboard.isDown("right") or joystick_01:isDown(13) then
    x = x + (speed * dt)
  end

  if love.keyboard.isDown("up") or joystick_01:isDown(14) then
    y = y - (speed * dt)
  end

  if love.keyboard.isDown("down") or joystick_01:isDown(15) then
    y = y + (speed * dt)
  end
end

function love.draw()
  -- love.graphics.draw(hamster, x, y)

  love.graphics.rectangle("fill", x, y, 40, 40)

  -- love.graphics.setColor(0, 255, 0, 255)
  -- love.graphics.print("dt: " .. love_dt, 10, 20)
  -- love.graphics.print("fps: " .. fps, 10, 40)
  -- love.graphics.reset()
end

function get_joystick()
  joystick_01 = love.joystick.getJoysticks()[1]
end
